@@ -4,7 +4,7 @@ use Moose;
 with 'Dist::Zilla::Role::MintingProfile::ShareDir';
 use namespace::clean;
 
-our $VERSION = 'v1.0.1';
+our $VERSION = 'v1.0.2';
 
 __PACKAGE__->meta->make_immutable;
 1;
@@ -30,10 +30,6 @@ C<Changes>
 
 =item *
 
-C<cpanfile>
-
-=item *
-
 C<dist.ini>
 
 =item *
@@ -42,6 +38,10 @@ C<LICENSE>
 
 =item *
 
+C<prereqs.yml>
+
+=item *
+
 C<.gitignore>
 
 =item *
@@ -71,4 +71,4 @@ the terms of the Artistic License version 2.0.
 
 =head1 SEE ALSO
 
-L<Dist::Zilla>, L<cpanfile>, L<Dist::Zilla::PluginBundle::Author::DBOOK>
+L<Dist::Zilla>, L<Dist::Zilla::PluginBundle::Author::DBOOK>
